package com.hw.wms.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.hw.common.log.annotation.Log;
import com.hw.common.log.enums.BusinessType;
import com.hw.common.security.annotation.RequiresPermissions;
import com.hw.wms.domain.WmsStockTotal;
import com.hw.wms.service.IWmsStockTotalService;
import com.hw.common.core.web.controller.BaseController;
import com.hw.common.core.web.domain.AjaxResult;
import com.hw.common.core.utils.poi.ExcelUtil;
import com.hw.common.core.web.page.TableDataInfo;

/**
 * 原材料/成品库存Controller
 * 
 * @author xins
 * @date 2024-03-14
 */
@RestController
@RequestMapping("/stocktotal")
public class WmsStockTotalController extends BaseController
{
    @Autowired
    private IWmsStockTotalService wmsStockTotalService;

    /**
     * 查询原材料/成品库存列表
     */
    @RequiresPermissions("wms:stocktotal:list")
    @GetMapping("/list")
    public TableDataInfo list(WmsStockTotal wmsStockTotal)
    {
        startPage();
        List<WmsStockTotal> list = wmsStockTotalService.selectWmsStockTotalList(wmsStockTotal);
        return getDataTable(list);
    }

    /**
     * 导出原材料/成品库存列表
     */
    @RequiresPermissions("wms:stocktotal:export")
    @Log(title = "原材料/成品库存", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, WmsStockTotal wmsStockTotal)
    {
        List<WmsStockTotal> list = wmsStockTotalService.selectWmsStockTotalList(wmsStockTotal);
        ExcelUtil<WmsStockTotal> util = new ExcelUtil<WmsStockTotal>(WmsStockTotal.class);
        util.exportExcel(response, list, "原材料/成品库存数据");
    }

    /**
     * 获取原材料/成品库存详细信息
     */
    @RequiresPermissions("wms:stocktotal:query")
    @GetMapping(value = "/{stockTotalId}")
    public AjaxResult getInfo(@PathVariable("stockTotalId") Long stockTotalId)
    {
        return success(wmsStockTotalService.selectWmsStockTotalByStockTotalId(stockTotalId));
    }

    /**
     * 新增原材料/成品库存
     */
    @RequiresPermissions("wms:stocktotal:add")
    @Log(title = "原材料/成品库存", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody WmsStockTotal wmsStockTotal)
    {
        return toAjax(wmsStockTotalService.insertWmsStockTotal(wmsStockTotal));
    }

    /**
     * 修改原材料/成品库存
     */
    @RequiresPermissions("wms:stocktotal:edit")
    @Log(title = "原材料/成品库存", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody WmsStockTotal wmsStockTotal)
    {
        return toAjax(wmsStockTotalService.updateWmsStockTotal(wmsStockTotal));
    }

    /**
     * 删除原材料/成品库存
     */
    @RequiresPermissions("wms:stocktotal:remove")
    @Log(title = "原材料/成品库存", businessType = BusinessType.DELETE)
	@DeleteMapping("/{stockTotalIds}")
    public AjaxResult remove(@PathVariable Long[] stockTotalIds)
    {
        return toAjax(wmsStockTotalService.deleteWmsStockTotalByStockTotalIds(stockTotalIds));
    }
}
